@@ -203,8 +203,9 @@ current repl's (as per slime-output-buffer) window."
     (slime-set-query-on-exit-flag stream)
     (set-process-filter stream 'slime-output-filter)
     (set-process-coding-system stream emacs-coding-system emacs-coding-system)
-    (when-let (secret (slime-secret))
-      (slime-net-send secret stream))
+    (let ((secret (slime-secret)))
+      (when secret
+	(slime-net-send secret stream)))
     (run-hook-with-args 'slime-open-stream-hooks stream)
     stream))
 
@@ -544,11 +545,12 @@ joined together."))
 (defun slime-repl-eval-string (string)
   (slime-rex ()
       ((if slime-repl-auto-right-margin
-           `(swank:listener-eval ,string
-                                 :window-width
-                                 ,(with-current-buffer (slime-output-buffer)
-                                    (window-width)))
-         `(swank:listener-eval ,string))
+           `(swank-repl:listener-eval
+	     ,string
+	     :window-width
+	     ,(with-current-buffer (slime-output-buffer)
+		(window-width)))
+         `(swank-repl:listener-eval ,string))
        (slime-lisp-package))
     ((:ok result)
      (slime-repl-insert-result result))
@@ -559,7 +561,7 @@ joined together."))
   (with-current-buffer (slime-output-buffer)
     (save-excursion
       (when result
-        (destructure-case result
+        (slime-dcase result
           ((:values &rest strings)
            (cond ((null strings)
                   (slime-repl-emit-result "; No value\n" t))
@@ -878,11 +880,12 @@ used with a prefix argument (C-u), doesn't switch back afterwards."
 (defun slime-repl-input-line-beginning-position ()
   (save-excursion
     (goto-char slime-repl-input-start-mark)
-    (line-beginning-position)))
+    (let ((inhibit-field-text-motion t))
+      (line-beginning-position))))
 
 (defun slime-clear-repl-variables ()
   (interactive)
-  (slime-eval-async `(swank:clear-repl-variables)))
+  (slime-eval-async `(swank-repl:clear-repl-variables)))
 
 (defvar slime-repl-clear-buffer-hook)
 
@@ -1506,7 +1509,7 @@ expansion will be added to the REPL's history.)"
       (let ((marker (copy-marker (buffer-size)))
             (target (incf slime-last-output-target-id)))
         (puthash target marker slime-output-target-to-marker)
-        (slime-eval `(swank:redirect-trace-output ,target))))
+        (slime-eval `(swank-repl:redirect-trace-output ,target))))
     ;; Note: We would like the entries in
     ;; slime-output-target-to-marker to disappear when the buffers are
     ;; killed.  We cannot just make the hash-table ":weakness 'value"
@@ -1558,7 +1561,7 @@ expansion will be added to the REPL's history.)"
     (let ((toplevel (slime-parse-toplevel-form)))
       (if (symbolp toplevel)
           (error "Not in a function definition")
-        (destructure-case toplevel
+        (slime-dcase toplevel
           (((:defun :defgeneric :defmacro :define-compiler-macro) symbol)
            (insert-call symbol))
           ((:defmethod symbol &rest args)
@@ -1572,10 +1575,10 @@ expansion will be added to the REPL's history.)"
            (error "Not in a function definition")))))))
 
 (defun slime-repl-copy-down-to-repl (slimefun &rest args)
-  (slime-eval-async `(swank:listener-save-value ',slimefun ,@args)
+  (slime-eval-async `(swank-repl:listener-save-value ',slimefun ,@args)
     #'(lambda (_ignored)
         (with-current-buffer (slime-repl)
-          (slime-eval-async '(swank:listener-get-value)
+          (slime-eval-async '(swank-repl:listener-get-value)
             #'(lambda (_ignored)
                 (slime-repl-insert-prompt)))))))
 
@@ -1588,12 +1591,12 @@ expansion will be added to the REPL's history.)"
 (defun sldb-copy-down-to-repl (frame-id var-id)
   "Evaluate the frame var at point via the REPL (to set `*')."
   (interactive (list (sldb-frame-number-at-point) (sldb-var-number-at-point)))
-  (slime-repl-copy-down-to-repl 'swank-backend:frame-var-value frame-id var-id))
+  (slime-repl-copy-down-to-repl 'swank/backend:frame-var-value frame-id var-id))
 
 (defun sldb-insert-frame-call-to-repl ()
   "Insert a call to a frame at point."
   (interactive)
-  (let ((call (slime-eval `(swank-backend::frame-call
+  (let ((call (slime-eval `(swank/backend::frame-call
                             ,(sldb-frame-number-at-point)))))
     (slime-switch-to-output-buffer)
     (if (>= (point) slime-repl-prompt-start-mark)
@@ -1707,14 +1710,14 @@ expansion will be added to the REPL's history.)"
   (destructuring-bind (package prompt)
       (let ((slime-current-thread t)
 	    (cs (slime-repl-choose-coding-system)))
-	(slime-eval `(swank:create-repl nil :coding-system ,cs)))
+	(slime-eval `(swank-repl:create-repl nil :coding-system ,cs)))
     (setf (slime-lisp-package) package)
     (setf (slime-lisp-package-prompt-string) prompt))
   (slime-hide-inferior-lisp-buffer)
   (slime-init-output-buffer (slime-connection)))
 
 (defun slime-repl-event-hook-function (event)
-  (destructure-case event
+  (slime-dcase event
     ((:write-string output &optional target)
      (slime-write-string output target)
      t)
